@@ -18,7 +18,7 @@ def selfcheck(
     schoolname: str,
     level: str,
     password: str,
-    docheck: str = "0",
+    docheck: str = "0", # 진단키드 사용여부
     customloginname: str = None,
     loop=asyncio.get_event_loop(),
 ):
@@ -83,7 +83,7 @@ async def asyncSelfCheck(
     schoolname: str,
     level: str,
     password: str,
-    docheck: str = "0",
+    docheck: str = "0", # 진단키드 사용여부
     customloginname: str = None,
 ):
     async with aiohttp.ClientSession() as session:
@@ -277,9 +277,15 @@ async def asyncUserLogin(
         }
 
     try:
+        mtk = mTransKey("https://hcs.eduro.go.kr/transkeyServlet")
+        pw_pad = await mtk.new_keypad("number", "password", "password", "password")
+        encrypted = pw_pad.encrypt_password(password)
+        hm = mtk.hmac_digest(encrypted.encode())
+        
+        
         res = await send_hcsreq(
             headers={"Content-Type": "application/json"},
-            endpoint="/v2/findUser",
+            endpoint="/v3/findUser",
             school=info["schoolurl"],
             json={
                 "orgCode": schoolcode,
@@ -288,6 +294,27 @@ async def asyncUserLogin(
                 "loginType": "school",
                 "searchKey": token,
                 "stdntPNo": None,
+                "orgName": schoolname,
+                "lctnScCode": info["schoolcode"],
+                "password": json.dumps(
+                    {
+                        "raon": [
+                            {
+                                "id": "password",
+                                "enc": encrypted,
+                                "hmac": hm,
+                                "keyboardType": "number",
+                                "keyIndex": mtk.keyIndex,
+                                "fieldType": "password",
+                                "seedKey": mtk.crypto.get_encrypted_key(),
+                                "initTime": mtk.initTime,
+                                "ExE2E": "false",
+                            }
+                        ]
+                    }
+                ),
+                "deviceUuid": "",
+                "makeSession": True,
             },
             session=session,
         )
